==> component_builder-2.2.2.tar.gz: component_builder/components/component_video_and_text/assets/style.js <==
/**
 * @file
 * Javascript functionality for component video and text.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.componentVideoAndText = Drupal.componentVideoAndText || {};
  Drupal.behaviors.videoAndText = {
    attach: function (context) {
      Drupal.componentVideoAndText.addButtonForVideo();
      Drupal.componentVideoAndText.handleClickVideo();
    }
  }

  Drupal.componentVideoAndText.addButtonForVideo = function () {
    const $component_item = $('.component-builder.component-item.component-item--type-video-and-text');
    if ($component_item.length > 0) {
      $component_item.each(function () {
        let $field_group_text = $component_item.find('fieldset.group-video-text');
        let $markupButton = '<button class = "video-button stop"></button>'
        if ($field_group_text.length > 0) {
          $field_group_text.once('addMarkupItem').prepend($markupButton);
        }
      });
    }
  }

  Drupal.componentVideoAndText.handleClickVideo = function () {
    const $component_item = $(".component-builder.component-item.component-item--type-video-and-text");
    if ($component_item.length > 0) {
      $component_item.each(function () {
        let $component_item = $(this);
        let $video = $component_item.find("video.video--field-vat-video");
        if ($video.length > 0) {
          $video.each(function () {
            $(this).once('click').on('click', function () {
              let $videoSelector = $(this);
              let $button = $component_item.find('button.video-button');
              if ($button.length > 0) {
                $button.each(function () {
                  $(this).toggleClass('stop').once("toggleClassStop");
                  $(this).toggleClass('play').once("toggleClassPlay");
                });
              }
              let $text_wrapper = $component_item.find('div.fieldset__wrapper');
              if ($text_wrapper.length > 0) {
                $text_wrapper.each(function () {
                  if ($(this).css('display') === 'none') {
                    $(this).css('display', 'block').once('displayBlockText');
                    // $videoSelector.removeAttr("controls").once('removeAttribute');
                    $videoSelector.trigger("pause");
                  }
                  else if ($(this).css('display') === 'block') {
                    $(this).css('display', 'none').once('displayNoneText');
                    // $videoSelector.attr('controls', '').once('controlShow');
                    $videoSelector.trigger("play");
                  }
                });
              }
            });
          });
        }

        let $button = $component_item.find("button.video-button");
        if ($button.length > 0) {
          $button.each(function () {
            $(this).once('clickButton').click(function () {
              $(this).toggleClass('stop').once("toggleClassStop");
              $(this).toggleClass('play').once("toggleClassPlay");

              if ($video.length > 0) {
                $video.each(function () {
                  // console.log($(this))
                  // if ($(this).paused) {
                  //   console.log("play");
                    $(this).trigger("play");
                  // }
                });
              }

              let $text_wrapper = $component_item.find('div.fieldset__wrapper');
              if ($text_wrapper.length > 0) {
                $text_wrapper.each(function () {
                  if ($(this).css('display') === 'none') {
                    $(this).css('display', 'block').once('displayBlockText');
                  }
                  else if ($(this).css('display') === 'block') {
                    $(this).css('display', 'none').once('displayNoneText');
                  }
                });
              }
            })
          });
        }

      });
    }
  };

})(jQuery, Drupal);

==> component_builder-3.0.1.tar.gz: component_builder/components/component_video_and_text/assets/style.js <==
/**
 * @file
 * Javascript functionality for component video and text.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.componentVideoAndText = Drupal.componentVideoAndText || {};
  Drupal.behaviors.videoAndText = {
    attach: function (context) {
      Drupal.componentVideoAndText.addButtonForVideo();
      Drupal.componentVideoAndText.handleClickVideo();
    }
  }

  Drupal.componentVideoAndText.addButtonForVideo = function () {
    const $component_item = $('.component-builder.component-item.component-item--type-video-and-text');
    if ($component_item.length > 0) {
      $component_item.each(function () {
        let $field_group_text = $component_item.find('.group-video-text');
        let $markupButton = '<button class = "video-button stop"></button>'
        if ($field_group_text.length > 0) {
          $field_group_text.once('addMarkupItem').prepend($markupButton);
        }
      });
    }
  }

  Drupal.componentVideoAndText.handleClickVideo = function () {
    const $component_item = $(".component-builder.component-item.component-item--type-video-and-text");
    if ($component_item.length > 0) {
      $component_item.each(function () {
        let $component_item = $(this);
        let $video = $component_item.find("video.video--field-vat-video");
        if ($video.length > 0) {
          $video.each(function () {
            $(this).once('click').on('click', function () {
              let $videoSelector = $(this);
              let $button = $component_item.find('button.video-button');
              if ($button.length > 0) {
                $button.each(function () {
                  $(this).toggleClass('stop').once("toggleClassStop");
                  $(this).toggleClass('play').once("toggleClassPlay");
                });
              }
              let $text_wrapper = $component_item.find('div.group-text');
              if ($text_wrapper.length > 0) {
                $text_wrapper.each(function () {
                  if ($(this).css('display') === 'none') {
                    $(this).css('display', 'block').once('displayBlockText');
                    // $videoSelector.removeAttr("controls").once('removeAttribute');
                    $videoSelector.trigger("pause");
                  }
                  else if ($(this).css('display') === 'block') {
                    $(this).css('display', 'none').once('displayNoneText');
                    // $videoSelector.attr('controls', '').once('controlShow');
                    $videoSelector.trigger("play");
                  }
                });
              }
            });
          });
        }

        let $button = $component_item.find("button.video-button");
        if ($button.length > 0) {
          $button.each(function () {
            $(this).once('clickButton').click(function () {
              $(this).toggleClass('stop').once("toggleClassStop");
              $(this).toggleClass('play').once("toggleClassPlay");

              if ($video.length > 0) {
                $video.each(function () {
                    $(this).trigger("play");
                  // }
                });
              }

              let $text_wrapper = $component_item.find('div.group-text');
              if ($text_wrapper.length > 0) {
                $text_wrapper.each(function () {
                  if ($(this).css('display') === 'none') {
                    $(this).css('display', 'block').once('displayBlockText');
                  }
                  else if ($(this).css('display') === 'block') {
                    $(this).css('display', 'none').once('displayNoneText');
                  }
                });
              }
            })
          });
        }

      });
    }
  };

})(jQuery, Drupal);
